Raven
======

Raven is a Python client for `Sentry <http://aboutsentry.com/>`_. It provides
full out-of-the-box support for many of the popular frameworks, including
Django, and Flask. Raven also includes drop-in support for any WSGI-compatible
web application.

Your application doesn't live on the web? No problem! Raven is easy to use in
any Python application.

**Raven 1.0 requires at least version 2.0 of Sentry to be installed on the server**

Resources
---------

* `Documentation <http://raven.readthedocs.org/>`_
* `Bug Tracker <http://github.com/dcramer/raven/issues>`_
* `Code <http://github.com/dcramer/raven>`_
* `Mailing List <https://groups.google.com/group/disqus-opensource>`_
* `IRC <irc://irc.freenode.net/sentry>`_  (irc.freenode.net, #sentry)
